==> recruit-drop-list-1.0.27.tgz: package/lib/createPage.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import React, { Component } from 'react';
import Textbox from './textbox';
var emailTest = /^(\w-*\.*)+@(\w-?)+(\.\w{2,})+$/;
var phoneTest = /^1\d{10}$/;

var CreatePage =
/*#__PURE__*/
function (_Component) {
  _inherits(CreatePage, _Component);

  function CreatePage(props) {
    var _this;

    _classCallCheck(this, CreatePage);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(CreatePage).call(this, props));
    _this.state = {
      nameRequired: false,
      emailRequired: false,
      wrongEmail: false,
      wrongPhone: false,
      nameValue: '',
      emailValue: '',
      phoneValue: '',
      isEmailError: false
    };
    _this.validateAll = _this.validateAll.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }

  _createClass(CreatePage, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.isEmailError !== this.state.isEmailError) {
        this.setState({
          isEmailError: nextProps.isEmailError
        });
      }
    }
  }, {
    key: "isRequired",
    value: function isRequired(value) {
      return value == '';
    }
  }, {
    key: "validateAll",
    value: function validateAll() {
      this.validateName(this.state.nameValue);
      this.validateEmail(this.state.emailValue);
      this.validateEmailDuplicate(this.state.emailValue);
      this.validatePhone(this.state.phoneValue);
    }
  }, {
    key: "validateName",
    value: function validateName(value) {
      this.setState({
        nameValue: value,
        nameRequired: this.isRequired(value)
      });
    }
  }, {
    key: "validateEmail",
    value: function validateEmail(value) {
      if (value == '') {
        this.setState({
          emailValue: '',
          emailRequired: true
        });
      } else {
        this.setState({
          emailValue: value,
          wrongEmail: !emailTest.test(value)
        });
      }
    }
  }, {
    key: "validateEmailDuplicate",
    value: function validateEmailDuplicate(value) {
      this.props.validateEmail && this.props.validateEmail(value);
    }
  }, {
    key: "validatePhone",
    value: function validatePhone(value) {
      if (value == '') {
        this.setState({
          phoneValue: '',
          wrongPhone: false
        });
      } else {
        this.setState({
          phoneValue: value,
          wrongPhone: !phoneTest.test(value)
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var self = this;
      var _this$state = this.state,
          nameValue = _this$state.nameValue,
          emailValue = _this$state.emailValue,
          phoneValue = _this$state.phoneValue,
          nameRequired = _this$state.nameRequired,
          emailRequired = _this$state.emailRequired,
          wrongEmail = _this$state.wrongEmail,
          wrongPhone = _this$state.wrongPhone,
          isEmailError = _this$state.isEmailError;
      var props1 = {
        showTag: '姓名',
        defaultValue: nameValue,
        required: true,
        errorStatus: nameRequired,
        errorMsg: '请填写姓名',
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validateName(value);
        }
      };
      var props2 = {
        showTag: '邮箱',
        defaultValue: emailValue,
        required: true,
        errorStatus: emailRequired || wrongEmail || isEmailError,
        errorMsg: emailRequired ? '请填写邮箱' : wrongEmail ? '邮箱格式错误' : this.props.emailErrorTip,
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validateEmail(value);
          self.validateEmailDuplicate(value);
        }
      };
      var props3 = {
        showTag: '手机',
        defaultValue: phoneValue,
        required: false,
        errorStatus: wrongPhone,
        errorMsg: '手机格式错误',
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validatePhone(value);
        }
      };
      return React.createElement("div", {
        className: "create-page"
      }, React.createElement(Textbox, props1), React.createElement(Textbox, props2), React.createElement(Textbox, props3));
    }
  }]);

  return CreatePage;
}(Component);

export { CreatePage as default };

==> recruit-drop-list-1.0.29.tgz: package/lib/createPage.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _inherits from "@babel/runtime/helpers/inherits";
import React, { Component } from 'react';
import Textbox from './textbox';
var emailTest = /^(\w-*\.*)+@(\w-?)+(\.\w{2,})+$/;
var phoneTest = /^1\d{10}$/;

var CreatePage =
/*#__PURE__*/
function (_Component) {
  _inherits(CreatePage, _Component);

  function CreatePage(props) {
    var _this;

    _classCallCheck(this, CreatePage);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(CreatePage).call(this, props));
    _this.state = {
      nameRequired: false,
      emailRequired: false,
      wrongEmail: false,
      wrongPhone: false,
      nameValue: '',
      emailValue: '',
      phoneValue: '',
      isEmailError: false
    };
    _this.validateAll = _this.validateAll.bind(_assertThisInitialized(_this));
    return _this;
  }

  _createClass(CreatePage, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.isEmailError !== this.state.isEmailError) {
        this.setState({
          isEmailError: nextProps.isEmailError
        });
      }
    }
  }, {
    key: "isRequired",
    value: function isRequired(value) {
      return value == '';
    }
  }, {
    key: "validateAll",
    value: function validateAll() {
      this.validateName(this.state.nameValue);
      this.validateEmail(this.state.emailValue);
      this.validateEmailDuplicate(this.state.emailValue);
      this.validatePhone(this.state.phoneValue);
    }
  }, {
    key: "validateName",
    value: function validateName(value) {
      this.setState({
        nameValue: value,
        nameRequired: this.isRequired(value)
      });
    }
  }, {
    key: "validateEmail",
    value: function validateEmail(value) {
      if (value == '') {
        this.setState({
          emailValue: '',
          emailRequired: true
        });
      } else {
        this.setState({
          emailValue: value,
          wrongEmail: !emailTest.test(value)
        });
      }
    }
  }, {
    key: "validateEmailDuplicate",
    value: function validateEmailDuplicate(value) {
      this.props.validateEmail && this.props.validateEmail(value);
    }
  }, {
    key: "validatePhone",
    value: function validatePhone(value) {
      if (value == '') {
        this.setState({
          phoneValue: '',
          wrongPhone: false
        });
      } else {
        this.setState({
          phoneValue: value,
          wrongPhone: !phoneTest.test(value)
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var self = this;
      var _this$state = this.state,
          nameValue = _this$state.nameValue,
          emailValue = _this$state.emailValue,
          phoneValue = _this$state.phoneValue,
          nameRequired = _this$state.nameRequired,
          emailRequired = _this$state.emailRequired,
          wrongEmail = _this$state.wrongEmail,
          wrongPhone = _this$state.wrongPhone,
          isEmailError = _this$state.isEmailError;
      var props1 = {
        showTag: '姓名',
        defaultValue: nameValue,
        required: true,
        errorStatus: nameRequired,
        errorMsg: '请填写姓名',
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validateName(value);
        }
      };
      var props2 = {
        showTag: '邮箱',
        defaultValue: emailValue,
        required: true,
        errorStatus: emailRequired || wrongEmail || isEmailError,
        errorMsg: emailRequired ? '请填写邮箱' : wrongEmail ? '邮箱格式错误' : this.props.emailErrorTip,
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validateEmail(value);
          self.validateEmailDuplicate(value);
        }
      };
      var props3 = {
        showTag: '手机',
        defaultValue: phoneValue,
        required: false,
        errorStatus: wrongPhone,
        errorMsg: '手机格式错误',
        lablePos: true,
        //label位置，true时在左边，false在上边
        onChange: function onChange(event, status, value) {},
        onBlur: function onBlur(event, status, value) {
          self.validatePhone(value);
        }
      };
      return React.createElement("div", {
        className: "create-page"
      }, React.createElement(Textbox, props1), React.createElement(Textbox, props2), React.createElement(Textbox, props3));
    }
  }]);

  return CreatePage;
}(Component);

export { CreatePage as default };
